@@ -39,30 +39,40 @@ class Act(object):
     """lightweight container class for action references and parameters
 
     """
-    __slots__ = ('actor', 'parms')
+    __slots__ = ('actor', 'parms', 'frame', 'context', 'act', 'iois')
 
-    def __init__(self, actor=None, parms=None, **kw ):
-        """Initialization method for instance.
+    def __init__(self, actor=None, parms=None, frame=None, context=None,
+                     act=None, iois=None, **kwa ):
+        """ Initialization method for instance.
 
-           attributes
-           .actor = Actor instance callable , call performs instances method action
-           .parms = dictionary of keyword arguments for .act
+            attributes
+                .actor = Actor instance callable , call performs instances method action
+                .parms = dictionary of keyword arguments for .act
+                .frame = Frame reference to frame holding act
+                .context = Action execution context name string set when added to frame
+                .act = Act reference if act in embedded in another act such as Need
+                .iois = dictionary of share initializers of parms with same key
 
         """
-        super(Act,self).__init__(**kw)
+        super(Act,self).__init__()
 
         self.actor = actor #callable instance performs action
         self.parms = parms or {}
+        self.frame = frame
+        self.context = context
+        self.act = act
+        self.iois = iois
+        
+        self.parms['_act'] = self
 
     def __call__(self): #make Act instance callable as function
-        """Define act as callable object
-
-        """
+        """ Define act as callable object """
         return (self.actor(**self.parms))
 
     def expose(self):
-        """Show Actor and parms"""
-        console.terse("Act Actor {0} Parms {1}\n".format(self.actor, self.parms))
+        """ Show attributes"""
+        cconsole.terse("Act Actor {0} Parms {1} in Frame {2} Context {3} SuperAct {4}\n".format(
+                    self.actor, self.parms, self.frame, self.context, self.act))
         if self.actor:
             self.actor.expose()
             
@@ -85,27 +95,33 @@ class Act(object):
         self.parms.update(parms)
 
     def resolveLinks(self, *pa, **kwa):
-        """Resolve any links in associated parms for actors
-           Should be overridden if use arguments
-        """
+        """ Resolve .frame attribute and any links in associated parms for .actor"""
+        if self.act: # sub act such as need of another act .act
+            self.frame = self.act.frame
+            self.context = self.act.context
+        self.frame = framing.resolveFrame(self.frame, who=self)
+        
         parms = self.actor.resolveLinks(**self.parms)
         self.parms.update(parms) 
 
 class Nact(Act):
-    """lightweight container class for action references and parameters
-       Negating Act used for actor needs to give Not Need
+    """ Negating Act used for actor needs to give Not Need
     """
-    __slots__ = ('actor', 'parms')
+    __slots__ = ('actor', 'parms', 'frame', 'context', 'act', 'iois')
 
-    def __init__(self, **kw ):
-        """Initialization method for instance.
+    def __init__(self, **kwa ):
+        """ Initialization method for instance.
 
-           Inherited attributes
-              .actor = Actor instance callable , call performs instances method action
-              .parms = dictionary of keyword arguments for .act
+            Inherited attributes
+                .actor = Actor instance callable , call performs instances method action
+                .parms = dictionary of keyword arguments for .act
+                .frame = Frame reference to frame holding act
+                .context = Action execution context name string
+                .act = Act reference if act in embedded in another act such as Need
+                .iois = dictionary of share initializers of parms with same key
 
         """
-        super(Nact,self).__init__(**kw)
+        super(Nact,self).__init__(**kwa)
 
 
     def __call__(self): #make Act instance callable as function
@@ -116,8 +132,9 @@ class Nact(Act):
 
 
     def expose(self):
-        """Show Actor and Parms"""
-        console.terse("Nact Actor {0} Parms {1}\n".format(self.actor, self.parms))
+        """ Show attributes """
+        console.terse("Nact Actor {0} Parms {1} in Frame {2} Context {3} SuperAct {4}\n".format(
+                    self.actor, self.parms, self.frame, self.context, self.act))
         if self.actor:
             self.actor.expose()
 
@@ -130,7 +147,7 @@ class Actor(registering.StoriedRegistry):
     Counter = 0  
     Names = {}
 
-    def __init__(self, name = 'actor', **kw ):
+    def __init__(self, name = 'actor', **kwa ):
         """Initialization method for instance.
 
            inherited attributes
@@ -138,20 +155,20 @@ class Actor(registering.StoriedRegistry):
               .store = shared data store
 
         """
-        if 'preface' not in kw:
-            kw['preface'] = 'Actor'
+        if 'preface' not in kwa:
+            kwa['preface'] = 'Actor'
 
-        super(Actor,self).__init__(name = name, **kw)
+        super(Actor,self).__init__(name = name, **kwa)
     
-    def __call__(self, **kw):
+    def __call__(self, **kwa):
         """run .action
 
         """
-        return self.action(**kw)
+        return self.action(**kwa)
     
-    def action(self, **kw):
+    def action(self, **kwa):
         """Action called by Actor. Should override in subclass."""
-        console.profuse("Actioning {0} with {1}\n".format(self.name, str(kw)))
+        console.profuse("Actioning {0} with {1}\n".format(self.name, str(kwa)))
 
         pass
     
@@ -167,7 +184,7 @@ class Actor(registering.StoriedRegistry):
         """
         return self
        
-    def cloneParms(self, parms, clones, **kw):
+    def cloneParms(self, parms, clones, **kwa):
         """ Returns parms fixed up for framer cloning. This includes:
             Reverting any Frame links to name strings,
             Reverting non cloned Framer links into name strings
@@ -208,13 +225,25 @@ class Actor(registering.StoriedRegistry):
                         newShare.create(stuff)
                         parms[key] = newShare                    
 
-        return parms
+        return parms      
     
-    def resolveLinks(self, **kw):
+    def resolveLinks(self, _act, **kwa):
         """ Resolves any links in parms for Actor
             should be overridden by sub class
         """
-        return {} #empty parms
+        parms =  {}
+
+        if _act.iois:
+            for key, ioi in _act.iois.items():
+                if key in kwa:
+                    raise excepting.ResolveError("ResolveError: Parm and Ioi with same key", key, _act)
+                
+                parms[key] = storing.resolvePath(   store=self.store,
+                                                    ipath=ioi['ipath'],
+                                                    ival=ioi.get('ival'), 
+                                                    iown=ioi.get('iown'),
+                                                    act=_act)
+        return parms
 
 
 class Interrupter(Actor):
@@ -338,7 +367,7 @@ class Transiter(Interrupter):
         
         return parms    
         
-    def resolveLinks(self, needs, near, far, human, **kw):
+    def resolveLinks(self, _act, needs, near, far, human, **kw):
         """Resolve any links in far and in associated parms for actors"""
 
         parms = {}
@@ -369,6 +398,7 @@ class Transiter(Interrupter):
             parms['far'] = far #replace name with valid link
 
         for act in needs:
+            act.act = _act
             act.resolveLinks()
 
         return parms
@@ -496,7 +526,7 @@ class Suspender(Interrupter):
         
         return parms
 
-    def resolveLinks(self, needs, main, aux, human, **kw):
+    def resolveLinks(self, _act, needs, main, aux, human, **kw):
         """Resolve any links aux and in associated parms for actors"""
 
         parms = {}
@@ -519,6 +549,7 @@ class Suspender(Interrupter):
                                          main.name + " " + human, aux)
 
         for act in needs:
+            act.act = _act
             act.resolveLinks()
 
         return parms
